==> duckdb_0.3.2.tar.gz: duckdb/src/duckdb/amalgamation-14.cpp <==
#include "src/parser/transform/expression/transform_lambda.cpp"

#include "src/parser/transform/expression/transform_operator.cpp"

#include "src/parser/transform/expression/transform_param_ref.cpp"

#include "src/parser/transform/expression/transform_positional_reference.cpp"

#include "src/parser/transform/expression/transform_subquery.cpp"

#include "src/parser/transform/helpers/nodetype_to_string.cpp"

#include "src/parser/transform/helpers/transform_alias.cpp"

#include "src/parser/transform/helpers/transform_cte.cpp"

#include "src/parser/transform/helpers/transform_groupby.cpp"

#include "src/parser/transform/helpers/transform_orderby.cpp"

#include "src/parser/transform/helpers/transform_sample.cpp"

#include "src/parser/transform/helpers/transform_typename.cpp"

#include "src/parser/transform/statement/transform_alter_sequence.cpp"

#include "src/parser/transform/statement/transform_alter_table.cpp"

#include "src/parser/transform/statement/transform_call.cpp"

#include "src/parser/transform/statement/transform_checkpoint.cpp"

#include "src/parser/transform/statement/transform_copy.cpp"

#include "src/parser/transform/statement/transform_create_enum.cpp"

#include "src/parser/transform/statement/transform_create_function.cpp"

#include "src/parser/transform/statement/transform_create_index.cpp"

#include "src/parser/transform/statement/transform_create_schema.cpp"

#include "src/parser/transform/statement/transform_create_sequence.cpp"

#include "src/parser/transform/statement/transform_create_table.cpp"

#include "src/parser/transform/statement/transform_create_table_as.cpp"

#include "src/parser/transform/statement/transform_create_view.cpp"

#include "src/parser/transform/statement/transform_delete.cpp"

#include "src/parser/transform/statement/transform_drop.cpp"

#include "src/parser/transform/statement/transform_explain.cpp"

#include "src/parser/transform/statement/transform_export.cpp"

#include "src/parser/transform/statement/transform_import.cpp"

#include "src/parser/transform/statement/transform_insert.cpp"

#include "src/parser/transform/statement/transform_load.cpp"

#include "src/parser/transform/statement/transform_pragma.cpp"

#include "src/parser/transform/statement/transform_prepare.cpp"

#include "src/parser/transform/statement/transform_rename.cpp"

#include "src/parser/transform/statement/transform_select.cpp"

#include "src/parser/transform/statement/transform_select_node.cpp"

#include "src/parser/transform/statement/transform_set.cpp"

#include "src/parser/transform/statement/transform_show.cpp"

#include "src/parser/transform/statement/transform_show_select.cpp"

#include "src/parser/transform/statement/transform_transaction.cpp"

#include "src/parser/transform/statement/transform_update.cpp"

#include "src/parser/transform/statement/transform_vacuum.cpp"

#include "src/parser/transform/tableref/transform_base_tableref.cpp"

#include "src/parser/transform/tableref/transform_from.cpp"

#include "src/parser/transform/tableref/transform_join.cpp"

==> duckdb_0.3.4.tar.gz: duckdb/src/duckdb/amalgamation-14.cpp <==
#include "src/parser/transform/expression/transform_grouping_function.cpp"

#include "src/parser/transform/expression/transform_interval.cpp"

#include "src/parser/transform/expression/transform_is_null.cpp"

#include "src/parser/transform/expression/transform_lambda.cpp"

#include "src/parser/transform/expression/transform_operator.cpp"

#include "src/parser/transform/expression/transform_param_ref.cpp"

#include "src/parser/transform/expression/transform_positional_reference.cpp"

#include "src/parser/transform/expression/transform_subquery.cpp"

#include "src/parser/transform/helpers/nodetype_to_string.cpp"

#include "src/parser/transform/helpers/transform_alias.cpp"

#include "src/parser/transform/helpers/transform_cte.cpp"

#include "src/parser/transform/helpers/transform_groupby.cpp"

#include "src/parser/transform/helpers/transform_orderby.cpp"

#include "src/parser/transform/helpers/transform_sample.cpp"

#include "src/parser/transform/helpers/transform_typename.cpp"

#include "src/parser/transform/statement/transform_alter_sequence.cpp"

#include "src/parser/transform/statement/transform_alter_table.cpp"

#include "src/parser/transform/statement/transform_call.cpp"

#include "src/parser/transform/statement/transform_checkpoint.cpp"

#include "src/parser/transform/statement/transform_copy.cpp"

#include "src/parser/transform/statement/transform_create_enum.cpp"

#include "src/parser/transform/statement/transform_create_function.cpp"

#include "src/parser/transform/statement/transform_create_index.cpp"

#include "src/parser/transform/statement/transform_create_schema.cpp"

#include "src/parser/transform/statement/transform_create_sequence.cpp"

#include "src/parser/transform/statement/transform_create_table.cpp"

#include "src/parser/transform/statement/transform_create_table_as.cpp"

#include "src/parser/transform/statement/transform_create_view.cpp"

#include "src/parser/transform/statement/transform_delete.cpp"

#include "src/parser/transform/statement/transform_drop.cpp"

#include "src/parser/transform/statement/transform_explain.cpp"

#include "src/parser/transform/statement/transform_export.cpp"

#include "src/parser/transform/statement/transform_import.cpp"

#include "src/parser/transform/statement/transform_insert.cpp"

#include "src/parser/transform/statement/transform_load.cpp"

#include "src/parser/transform/statement/transform_pragma.cpp"

#include "src/parser/transform/statement/transform_prepare.cpp"

#include "src/parser/transform/statement/transform_rename.cpp"

#include "src/parser/transform/statement/transform_select.cpp"

#include "src/parser/transform/statement/transform_select_node.cpp"

#include "src/parser/transform/statement/transform_set.cpp"

#include "src/parser/transform/statement/transform_show.cpp"

#include "src/parser/transform/statement/transform_show_select.cpp"

#include "src/parser/transform/statement/transform_transaction.cpp"

#include "src/parser/transform/statement/transform_update.cpp"

#include "src/parser/transform/statement/transform_vacuum.cpp"

#include "src/parser/transform/tableref/transform_base_tableref.cpp"
